.. _spkg_pyproject_hooks:

pyproject_hooks: Wrappers to call pyproject.toml-based build backend hooks.
=====================================================================================

Description
-----------

Wrappers to call pyproject.toml-based build backend hooks.

License
-------

Upstream Contact
----------------

https://pypi.org/project/pyproject_hooks/


Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    1.1.0

version_requirements.txt::

    pyproject_hooks


Equivalent System Packages
--------------------------

(none known)

